Starting month of the hydrological year (default = 1)
precip
Precipitation time series (default = FALSE)
dig
Number of significant digits for Value (default = 1)
Author
P. Chevallier - Nov 2022
Details
The function means the values of each calendar day over a period larger
than 4 years (i.e. it includes at least one Feb 29 day). The result is transfered
to the last possible hydrological year of the interval.
In the special case of precipitation, where the distribution is discontinuous
over time, the original values of the last hydrological year are replaced by values
corrected proportionately.